Learn R Programming

tfrmt (version 0.3.0)

body_plan: Table Body Plan

Description

Define the formatting of the body contents of the table through a series of frmt_structures. Structures get applied in order from bottom up, so the last added structure is the first applied.

Usage

body_plan(...)

Value

body_plan object

Arguments

...

list of frmt_structures defining the body formatting

See Also

frmt_structure() defines which rows the formats will be applied to, and frmt(), frmt_combine(), and frmt_when() define the format semantics.

Link to related article

Examples

Run this code

  tfrmt_spec<- tfrmt(
      title = "Table Title",
      body_plan = body_plan(
        frmt_structure(
          group_val = c("group1"),
          label_val = ".default",
          frmt("XXX")
        )
      )
     )

Run the code above in your browser using DataLab