Learn R Programming

tfrmt (version 0.3.0)

col_style_plan: Column Style Plan

Description

Define how the columns of the table body should be aligned, whether left, right or on a specific character(s).

Usage

col_style_plan(...)

Value

col_style_plan object

Arguments

...

series of col_style_structure objects

See Also

col_style_structure() for more information on how to specify how to and which columns to align.

Link to related article

Examples

Run this code

 plan <- col_style_plan(
    col_style_structure(col = "my_var", align = "left", width = 100),
    col_style_structure(col = vars(four), align = "right"),
    col_style_structure(col = vars(two, three), align = c(".", ",", " "))
   )



Run the code above in your browser using DataLab