Learn R Programming

tfrmt (version 0.3.0)

display_row_frmts: Display formatting applied to each row

Description

Used when debugging formatting, it is an easy way to allow you to see which formats are applied to each row in your dataset.

Usage

display_row_frmts(tfrmt, .data, convert_to_txt = TRUE)

Value

formatted tibble

Arguments

tfrmt

tfrmt object to apply to the data

.data

Data to apply the tfrmt to

convert_to_txt

Logical value converting formatting to text, by default TRUE

Examples

Run this code
 library(dplyr)
 library(tidyr)

 tfrmt_spec <- tfrmt(
 label = label,
 column = column,
 param = param,
 value=value,
 body_plan = body_plan(
   frmt_structure(group_val = ".default", label_val = ".default",
                  frmt_combine(
                    "{count} {percent}",
                    count = frmt("xxx"),
                    percent = frmt_when("==100"~ frmt(""),
                                        "==0"~ "",
                                        "TRUE" ~ frmt("(xx.x%)"))))
 ))

 # Create data
 df <- tidyr::crossing(label = c("label 1", "label 2"),
                column = c("placebo", "trt1"),
                param = c("count", "percent")) |>
   dplyr::mutate(value=c(24,19,2400/48,1900/38,5,1,500/48,100/38))

 display_row_frmts(tfrmt_spec,df)

Run the code above in your browser using DataLab