Location of the note describing each table's subset value(s).
Useful if the page_structure contains only ".default" values (meaning the
table is split by every unique level of a grouping variable), and that
variable is dropped in the col_plan. preheader only available for rtf output.
max_rows
Option to set a maximum number of rows per page. Takes a numeric value.