This utility function allows users to remove a specific component (e.g., body_plan,
row_grp_plan, col_plan) from a tfrmt object by setting it to NULL.
Examples
if (FALSE) { # \dontrun{
my_tfrmt <- tfrmt(column = "col1", label = "label1")
# Remove the column component
reset_tfrmt <- reset_component(my_tfrmt, "column")
} # }