This function creates an tfrmt for an n % table, so count based table. The
parameter values for n and percent can be provided (by default it will assume
n and pct). Additionally the frmt_when for formatting the percent can
be specified. By default 100% and 0% will not appear and everything between
99% and 100% and 0% and 1% will be rounded using greater than (>) and less
than (<) signs respectively.
tfrmt_n_pct(
n = "n",
pct = "pct",
pct_frmt_when = frmt_when("==100" ~ frmt(""), ">99" ~ frmt("(>99%)"), "==0" ~ "", "tfrmt object
name of count (n) value in the parameter column
name of percent (pct) value in the parameter column
formatting to be used on the the percent values
an optional tfrmt object to layer
print_mock_gt(tfrmt_n_pct())